@@ -3,9 +3,9 @@
  *
  * S H A P E   A N A L Y S Y S   R O U T I N E S
  *
- * $Revision: 1.21 $ $Date: 2004/01/26 20:47:58 $
+ * $Revision: 1.22 $ $Date: 2004/05/27 06:42:07 $
  *
- * ANIMAL - ANIMAL IMage Processing LibrarY
+ * ANIMAL - AN IMAging Library
  * Copyright (C) 2002,2003  Ricardo Fabbri
  *
  * This program is free software; you can redistribute it and/or modify
@@ -185,7 +185,7 @@ exact_propagation(Img *image, ImgPUInt32 *label, list *seed, char side)
 
    sedr = grow_sedr(maxrad);
    if (!sedr) {
-      gan_err_register (fname, GAN_ERROR_FAILURE,"");
+      animal_err_register (fname, ANIMAL_ERROR_FAILURE,"");
       return NULL;                                    
    }
    img  = impad(image, maxrad, maxrad, 0); 
@@ -234,7 +234,7 @@ exact_propagation(Img *image, ImgPUInt32 *label, list *seed, char side)
          }
 			break;
       default:
-         GAN_ERR_FIRST("exact_propagation", GAN_ERROR_FAILURE, "Invalid side parameter", NULL);
+         ANIMAL_ERR_FIRST("exact_propagation", ANIMAL_ERROR_FAILURE, "Invalid side parameter", NULL);
    }
 
    maxdist = (unsigned) maxrad*maxrad;
@@ -544,14 +544,14 @@ msskl(Img *bin, char side, skl_algorithm alg)
       nh   = get_8_nhood();
       aimg = ift_euclidean_propagation(bin, cont, nh, side);
          if (!aimg) {
-            gan_err_register ("msskl", GAN_ERROR_FAILURE,""); 
+            animal_err_register ("msskl", ANIMAL_ERROR_FAILURE,""); 
             return NULL;
          }
       free_nhood(&nh);
    } else {
    	aimg = exact_propagation(bin, cont, lst, side);
          if (!aimg) {
-            gan_err_register ("msskl", GAN_ERROR_FAILURE,""); 
+            animal_err_register ("msskl", ANIMAL_ERROR_FAILURE,""); 
             return NULL;
          }
    }
