@@ -70,7 +70,7 @@
  * \a data. If \a data is not \c NULL, the number of \a data_words must be
  * enough to store \a no_bits bits.
  */
-Animal_BitArray *
+AnimalExport Animal_BitArray *
  animal_bit_array_form_data ( Animal_BitArray *ba,
                            Animal_BitWord *data, unsigned data_words,
                            unsigned int no_bits )
@@ -149,7 +149,7 @@ Animal_BitArray *
  *
  * Form new bit array of size \a no_bits using stack-style memory allocation.
  */
-Animal_BitArray *
+AnimalExport Animal_BitArray *
  animal_bit_array_ms_form ( Animal_MemoryStack *ms, Animal_BitArray *ba,
                          unsigned int no_bits )
 {
@@ -194,7 +194,7 @@ Animal_BitArray *
  *
  * Reset size of existing bit array \a ba to \a no_bits.
  */
-Animal_Bool
+AnimalExport Animal_Bool
  animal_bit_array_set_size ( Animal_BitArray *ba, unsigned int no_bits )
 {
    ba->no_words = ANIMAL_NO_BITWORDS(no_bits);
@@ -232,7 +232,7 @@ Animal_Bool
 /**
  * \brief Free bit array.
  */
-void
+AnimalExport void
  animal_bit_array_free ( Animal_BitArray *ba )
 {
    if ( ba->memory_stack == NULL )
@@ -255,7 +255,7 @@ void
  *
  * Free list of bit arrays starting with \a ba and terminated with \c NULL.
  */
-void
+AnimalExport void
  animal_bit_array_free_va ( Animal_BitArray *ba, ... )
 {
    va_list ap;
@@ -279,7 +279,7 @@ void
  *
  * Set all bits in bit array \a ba to the given boolean value \a val.
  */
-Animal_Bool
+AnimalExport Animal_Bool
  animal_bit_array_fill ( Animal_BitArray *ba , Animal_Bool val )
 {
    unsigned int ctr = ba->no_words;
@@ -299,7 +299,7 @@ Animal_Bool
  *
  * Invert all the bits in a bit array \a ba.
  */
-Animal_Bool
+AnimalExport Animal_Bool
  animal_bit_array_invert_i ( Animal_BitArray *ba )
 {
    unsigned int ctr = ba->no_words;
@@ -318,7 +318,7 @@ Animal_Bool
  * Invert all the bits in a bit array \a ba, returning the result as anew bit
  * array.
  */
-Animal_BitArray *
+AnimalExport Animal_BitArray *
  animal_bit_array_invert_s ( Animal_BitArray *ba )
 {
    unsigned int ctr = ba->no_words;
@@ -346,7 +346,7 @@ Animal_BitArray *
  * Perform binary AND operation between bit arrays \a ba and \a ba_dst,
  * writing the result into \a ba_dst.
  */
-Animal_Bool
+AnimalExport Animal_Bool
  animal_bit_array_and_i ( Animal_BitArray *ba_dst, Animal_BitArray *ba )
 {
    unsigned int ctr = ba->no_words;
@@ -373,7 +373,7 @@ Animal_Bool
  * Perform binary NAND (not and) operation between bit arrays \a ba and
  * \a ba_dst, writing the result into \a ba_dst.
  */
-Animal_Bool
+AnimalExport Animal_Bool
  animal_bit_array_nand_i ( Animal_BitArray *ba_dst, Animal_BitArray *ba )
 {
    unsigned int ctr = ba->no_words;
@@ -401,7 +401,7 @@ Animal_Bool
  * Perform binary OR operation between bit arrays \a ba and \a ba_dst,
  * writing the result into \a ba_dst.
  */
-Animal_Bool
+AnimalExport Animal_Bool
  animal_bit_array_or_i ( Animal_BitArray *ba_dst, Animal_BitArray *ba )
 {
    unsigned int ctr = ba->no_words;
@@ -428,7 +428,7 @@ Animal_Bool
  * Perform binary EOR (exclusive or) operation between bit arrays \a ba and
  * \a ba_dst, writing the result into \a ba_dst.
  */
-Animal_Bool
+AnimalExport Animal_Bool
  animal_bit_array_eor_i ( Animal_BitArray *ba_dst, Animal_BitArray *ba )
 {
    unsigned int ctr = ba->no_words;
@@ -455,7 +455,7 @@ Animal_Bool
  * Perform binary AND-NOT operation between bit arrays \a ba and
  * \a ba_dst, writing the result into \a ba_dst.
  */
-Animal_Bool
+AnimalExport Animal_Bool
  animal_bit_array_andnot_i ( Animal_BitArray *ba_dst, Animal_BitArray *ba )
 {
    unsigned int ctr = ba->no_words;
@@ -482,7 +482,7 @@ Animal_Bool
  * Perform binary AND operation between bit arrays \a ba1 and \a ba2,
  * returning the result as a new bit array.
  */
-Animal_BitArray *
+AnimalExport Animal_BitArray *
  animal_bit_array_and_s  ( Animal_BitArray *ba1, Animal_BitArray *ba2 )
 {
    Animal_BitArray *ba_dst;
@@ -518,7 +518,7 @@ Animal_BitArray *
  * Perform binary NAND (not and) operation between bit arrays \a ba1 and
  * \a ba2, returning the result as a new bit array.
  */
-Animal_BitArray *
+AnimalExport Animal_BitArray *
  animal_bit_array_nand_s ( Animal_BitArray *ba1, Animal_BitArray *ba2 )
 {
    Animal_BitArray *ba_dst;
@@ -555,7 +555,7 @@ Animal_BitArray *
  * Perform binary OR operation between bit arrays \a ba1 and \a ba2,
  * returning the result as a new bit array.
  */
-Animal_BitArray *
+AnimalExport Animal_BitArray *
  animal_bit_array_or_s   ( Animal_BitArray *ba1, Animal_BitArray *ba2 )
 {
    Animal_BitArray *ba_dst;
@@ -591,7 +591,7 @@ Animal_BitArray *
  * Perform binary EOR (exclusive or) operation between bit arrays \a ba1 and
  * \a ba2, returning the result as a new bit array.
  */
-Animal_BitArray *
+AnimalExport Animal_BitArray *
  animal_bit_array_eor_s  ( Animal_BitArray *ba1, Animal_BitArray *ba2 )
 {
    Animal_BitArray *ba_dst;
@@ -627,7 +627,7 @@ Animal_BitArray *
  * Perform binary AND-NOT operation between bit arrays \a ba1 and
  * \a ba2, returning the result as a new bit array.
  */
-Animal_BitArray *
+AnimalExport Animal_BitArray *
  animal_bit_array_andnot_s ( Animal_BitArray *ba1, Animal_BitArray *ba2 )
 {
    Animal_BitArray *ba_dst;
@@ -667,7 +667,7 @@ Animal_BitArray *
  *
  * Insert part of bit array \a src in bit array \a dst
  */
-Animal_Bool
+AnimalExport Animal_Bool
  animal_bit_array_insert ( Animal_BitArray *src, unsigned int offset_src,
                         Animal_BitArray *dst, unsigned int offset_dst, 
                         unsigned int no_bits )
@@ -1312,7 +1312,7 @@ Animal_Bool
  *
  * Copy bit array \a ba_source to \a ba_dest.
  */
-Animal_Bool
+AnimalExport Animal_Bool
  animal_bit_array_copy_q ( Animal_BitArray *ba_source, Animal_BitArray *ba_dest )
 {
    /* make sure destination bit array can hold source bit array */
@@ -1336,7 +1336,7 @@ Animal_Bool
  *
  * Return a copy of bit array \a ba_source.
  */
-Animal_BitArray *
+AnimalExport Animal_BitArray *
  animal_bit_array_copy_s ( Animal_BitArray *ba_source )
 {
    Animal_BitArray *ba_dest = animal_bit_array_alloc(ba_source->no_bits);
@@ -1362,7 +1362,7 @@ Animal_BitArray *
  * Expand bit array \a ba by padding it with zeros in a reference bit array
  * \a ref_ba.
  */
-Animal_Bool
+AnimalExport Animal_Bool
  animal_bit_array_expand_q ( Animal_BitArray *ba, Animal_BitArray *ref_ba,
                           Animal_BitArray *exp_ba )
 {
@@ -1419,7 +1419,7 @@ Animal_Bool
  * Expand bit array \a ba by padding it with zeros in a reference bit array
  * \a ref_ba.
  */
-Animal_BitArray *
+AnimalExport Animal_BitArray *
  animal_bit_array_expand_s ( Animal_BitArray *ba, Animal_BitArray *ref_ba )
 {
    Animal_BitArray *exp_ba = animal_bit_array_alloc(ref_ba->no_bits);
@@ -1443,7 +1443,7 @@ Animal_BitArray *
  * given number of bits \a no_bits. The part is filled with the given boolean
  * value \a val.
  */
-Animal_Bool
+AnimalExport Animal_Bool
  animal_bit_array_fill_part ( Animal_BitArray *ba, unsigned int offset,
                            unsigned int no_bits, Animal_Bool val )
 {
@@ -1590,7 +1590,7 @@ Animal_Bool
  * Invert part of a bit array, specified by the start point \a offset and the
  * given number of bits \a no_bits.
  */
-Animal_Bool
+AnimalExport Animal_Bool
  animal_bit_array_invert_part ( Animal_BitArray *ba, unsigned int offset,
                              unsigned int no_bits )
 {
@@ -1651,7 +1651,7 @@ Animal_Bool
 /**
  * \brief Print bit array in ASCII to file.
  */
-void
+AnimalExport void
  animal_bit_array_fprint ( FILE *fp, Animal_BitArray *ba, int indent )
 {
    unsigned int i;
