@@ -179,6 +179,7 @@
 #ifndef _ANIMAL_ERR_H
 #define _ANIMAL_ERR_H
 
+#include <animal/common.h>
 #include <animal/base/misc_defs.h>
 
 #ifdef __cplusplus
@@ -272,25 +273,28 @@ void animal_err_register ( const char *func_name, int err_code,
 typedef enum { ANIMAL_ERR_TRACE_OFF, ANIMAL_ERR_TRACE_ON } Animal_TraceMode;
 
 
-Animal_ErrorReporterFunc
-          animal_err_set_reporter(Animal_ErrorReporterFunc app_error_reporter);
-Animal_ErrorReporterFunc animal_err_get_reporter( void );
-void animal_err_report( void );
-int animal_err_register_fileline(
+AnimalExport Animal_ErrorReporterFunc
+          animal_err_set_reporter(Animal_ErrorReporterFunc app_error_reporter),
+          animal_err_get_reporter( void );
+AnimalExport int 
+   animal_err_register_fileline(
                  const char * func_name,
                  int          err_code,
                  const char * file_name, /* Typically use __FILE__ */
                  int          line_number, /* Typically use __LINE__ */
-                 const char * message);
-void animal_err_set_trace( Animal_TraceMode trace_mode );
-void animal_err_flush_trace(void);
-int animal_err_get_error_count(void);
-int animal_err_get_error ( int           n,
+                 const char * message),
+   animal_err_get_error_count(void),
+   animal_err_get_error ( int           n,
                         const char ** func_name,
                         int         * err_code,
                         const char ** file_name,
                         int         * line_number,
                         const char ** message );
+AnimalExport void 
+   animal_err_report( void ),
+   animal_err_set_trace( Animal_TraceMode trace_mode ),
+   animal_err_flush_trace(void);
+
 
 /* error test macros compiled out when NDEBUG is defined */
 
