@@ -31,10 +31,6 @@
 #include "segment.h"
 #include "queue.h"
 
-bool edt_lz_vertical(ImgPUInt32 *im),
-     edt_lz_horizontal(ImgPUInt32 *im);
-
-
 
 /*----FUNCTION----------------------------------------------------------------
  * 
@@ -148,203 +144,6 @@ distance_transform(Img *bin, dt_algorithm alg)
    return cost; 
 }
 
-/* 
- * ========================================
- *  --------------------------------
- *    Lotufo-Zampirolli's fast EDT
- *  --------------------------------
- * ========================================
- */
-
-/*----FUNCTION-------------------------------------------------------------------------
- * 
- *  Description:  Lotufo-Zampirolli EDT (Euclidean Distance
- *  Transform): 
- *
- * REFERENCE
- *  R. Lotufo and F. Zampirolli, Fastmultidimensional parallel euclidean distance 
- *  transform based on mathematical morphology, in T. Wu and D. Borges, editors,
- *  Proccedings of SIBGRAPI 2001, XIV Brazilian Symposium on Computer Graphics 
- *  and Image Processing, pages 100-105. IEEE Computer Society, 2001.
- *  
- *  It is only internal EDT
- *
- *  TODO
- *    - take parameter "side" into account
- * 
- * - PARAMETER -------------------------------------------------------------------------
- *      Mode   Type             Name            Description
- * -------------------------------------------------------------------------------------
- *    in-out:  ImgPUInt32         im            binary image on input;
- *                                              grayscale on output, with internal 
- *                                              squared distance transform.
- *-------------------------------------------------------------------------------------*/
-
-AnimalExport bool
-edt_lz (ImgPUInt32 *im)
-{
-   int i, r,c;
-   puint32 infty;
-
-   assert(im->isbinary);
-
-   r = im->rows;
-   c = im->cols;
-   infty = PUINT32_MAX - r*r - c*c;
-
-   for (i=0; i < r*c; i++)
-      if (DATA(im)[i] == FG)
-         DATA(im)[i] = infty;
-
-   if ( !edt_lz_vertical(im) ) {
-      animal_err_register ("edt_lz_horizontal", ANIMAL_ERROR_FAILURE,""); 
-      return false;
-   }
-   if ( !edt_lz_horizontal(im) ) {
-      animal_err_register ("edt_lz_horizontal", ANIMAL_ERROR_FAILURE,""); 
-      return false;
-   }
-
-   im->isbinary = false;
-   return true;
-}
-
-
-/*----FUNCTION-------------------------------------------------------------------------
- * 
- *  Description:  Vertical erosions for Lotufo-Zampirolli EDT
- * 
- * - PARAMETER -------------------------------------------------------------------------
- *      Mode   Type             Name            Description
- * -------------------------------------------------------------------------------------
- *    in-out:  ImgPUInt32        im         binary input image; grayscale output.
- *                                          Foreground pixels must be PUINT32_MAX    
- *    return:  
- *-------------------------------------------------------------------------------------*/
-bool
-edt_lz_vertical(ImgPUInt32 *im)
-{
-   int   rows=im->rows, r,
-         cols=im->cols, c;
-   puint32 b;
-
-
-   for (c=0; c < cols; c++) {
-      b=1;
-      for (r=1; r<rows; r++)
-         if (RC(im,r,c) > RC(im,r-1,c) + b) {
-            RC(im,r,c) = RC(im,r-1,c) + b;
-            b += 2;
-         } else
-            b = 1;
-      b = 1;
-      for (r=rows-2; r >= 0; r--) {
-         if (RC(im,r,c) > RC(im,r+1,c) + b) {
-            RC(im,r,c) = RC(im,r+1,c) + b;
-            b += 2;
-         } else
-            b = 1;
-      }
-   }
-
-   return true;
-}
-
-
-/*----FUNCTION-------------------------------------------------------------------------
- * 
- *  Description:  Horizontal erosions for L-Z EDT
- *  TODO
- *    - Error trace/checking of return values
- *    - Optimize the queue
- *    - having tested the function, remove some error checking
- * 
- * - PARAMETER -------------------------------------------------------------------------
- *      Mode   Type             Name            Description
- * -------------------------------------------------------------------------------------
- *        in:   int            n                number of elements in queue 
- *-------------------------------------------------------------------------------------*/
-AnimalExport bool
-edt_lz_horizontal(ImgPUInt32 *im)
-{
-   SIQueue *Eq, *Eq2, *Wq, *Wq2, *tmp_q;
-   int nc, r, c;
-   puint32 b;
-   bool stat;
-
-   nc = im->cols;
-   Eq = siq_new(nc);   
-      if(!Eq) { /* report error using Gandalf */;
-         animal_err_register ("edt_lz_horizontal", ANIMAL_ERROR_FAILURE,"Demanding new Eq"); 
-         return false;
-      }
-   Eq2 = siq_new(nc);
-      if(!Eq2) { 
-         animal_err_register ("edt_lz_horizontal", ANIMAL_ERROR_FAILURE,"Demanding new Eq2"); 
-         return false;
-      }
-   Wq = siq_new(nc);
-      if(!Wq) { 
-         animal_err_register ("edt_lz_horizontal", ANIMAL_ERROR_FAILURE,"Demanding new Wq"); 
-         return false;
-      }
-   Wq2 = siq_new(nc);
-      if(!Wq2) { 
-         animal_err_register ("edt_lz_horizontal", ANIMAL_ERROR_FAILURE,"Demanding new Wq2"); 
-         return false;
-      }
-
-  /* I used assert in the following because the static queues shoudn't
-   * never overflow or underflow in this algorithm */
-
-   for (r=0; r<im->rows; r++) {
-      for (c=1; c < nc; c++) {
-         stat = siq_insert(Wq, c);   assert(stat);
-         stat = siq_insert(Eq, nc-1-c);   assert(stat);
-      }
-      b = 1;
-      while (!siq_is_empty(Wq) || !siq_is_empty(Eq)) {
-         while (!siq_is_empty(Eq)) {
-            stat = siq_remove(Eq, &c);   assert(stat);
-            if (RC(im,r,c+1) > RC(im,r,c) + b) {
-               RC(im,r,c+1) = RC(im,r,c) + b;
-               if (c+1 < nc-1) {
-                  stat = siq_insert(Eq2, c+1);   assert(stat);
-               }
-            }
-         }
-
-         while (!siq_is_empty(Wq)) {
-            stat = siq_remove(Wq, &c);   assert(stat);
-            if (RC(im,r,c-1) > RC(im,r,c) + b) {
-               RC(im,r,c-1) = RC(im,r,c) + b;
-               if (c-1 > 0) {
-                  stat = siq_insert(Wq2, c-1);   assert(stat);
-               }
-            }
-         }
-
-         b += 2;
-         tmp_q = Wq;
-         Wq    = Wq2;
-         Wq2   = tmp_q;
-         siq_reset(Wq2);
-
-         tmp_q = Eq;
-         Eq    = Eq2;
-         Eq2   = tmp_q;
-         siq_reset(Eq2);
-      }
-   }
-
-   siq_free(&Eq);
-   siq_free(&Wq);
-   siq_free(&Wq2);
-   siq_free(&Eq2);
-   
-   return true;
-}
-
 /* 
  * ========================================
  *  ----------------
@@ -393,10 +192,10 @@ edt_maurer2003(ImgPUInt32 *im)
          DATA(im)[i] = infty;
    
    // Vertical columnwise EDT
-   stat = edt_lz_vertical(im);
+   stat = edt_1d_vertical(im);
    // Lotufo's 1D EDT is equivalent to Maurer's D1.
    // There is a remark in section 5 of Maurer's paper that says
-   // D1 can be calculated using a propagation routine like this.
+   // D1 can be calculated using a routine like this.
    CHECK_RET_STATUS(false);
 
    stat = edt_maurer_2D_from_1D(im);      
