@@ -57,9 +57,11 @@ typedef enum {
 AnimalExport ImgPUInt32
    *distance_transform(Img *bin, dt_algorithm alg);
 
+
 AnimalExport bool
    distance_transform_ip(ImgPUInt32 *cost, dt_algorithm alg),
-   edt_lz (ImgPUInt32 *im),
+   edt_lz(ImgPUInt32 *im),
+   edt_lz_old(ImgPUInt32 *im),  /* more readable code but slower */
    edt_maurer2003(ImgPUInt32 *im),
    edt_ift(ImgPUInt32 *im, nhood *adj),
    edt_saito(ImgPUInt32 *im),
@@ -69,8 +71,9 @@ AnimalExport bool
    edt_cuisenaire_psn8(ImgPUInt32 *im),  // simple 8-nhood approx. EDT
    edt_cuisenaire_pmn (ImgPUInt32 *im),  // multiple nhood, exact EDT
    edt_cuisenaire_pmon(ImgPUInt32 *im),  // multiple oriented nhood,
-   edt_brute_force (ImgPUInt32 *im),     // O(n^4) algorithm just for benchmarks
-   edt_brute_force_with_list (ImgPUInt32 *im), // O(n^2)-O(n^4) algorithm
+   edt_brute_force(ImgPUInt32 *im),     // O(n^4) algorithm just for benchmarks
+   edt_brute_force_with_list(ImgPUInt32 *im), // O(n^2)-O(n^4) algorithm
+   edt_lz_step1_vertical(ImgPUInt32 *im), // 1D columwise EDT
    smallest_error_location(// generates a table of numbers for Cuisenaire.
          nhood *N, 
          puint32 *Derr_p, 
@@ -83,6 +86,8 @@ AnimalExport bool
          puint32 *derr_x, puint32 *derr_y, 
          puint32 start_dpx, puint32 start_dpy); 
 
+#define edt_1d_vertical(im) edt_lz_step1_vertical(im)
+
 END_C_DECLS
 
 #endif /* !DT_H */
