@@ -23,20 +23,20 @@ main (int argc, char *argv[])
 //   im2binary_ip(im);
    im = new_img(10,10);
    im->isbinary=true;
-   imset(im,0);
-//   RC(im,0,0)=0;
+   imset(im,1);
+   RC(im,0,0)=0;
    printf("%dx%d image\n",im->cols,im->rows);
    //imshow(im,0,-1);
 
    /* Uncomment the following to experiment the methods */
-//   img = distance_transform(im, DT_LOTUFO_ZAMPIROLLI);
+   img = distance_transform(im, DT_LOTUFO_ZAMPIROLLI);
 //   img = distance_transform(im, DT_MAURER2003);
 //   img = distance_transform(im, DT_CUISENAIRE_PMON_1999);
 //   img = distance_transform(im, DT_CUISENAIRE_PMN_1999);
 //   img = distance_transform(im, DT_CUISENAIRE_PSN8_1999);
 //   img = distance_transform(im, DT_IFT_8);
 //   img = distance_transform(im, DT_EXACT_DILATIONS);
-   img = distance_transform(im, DT_BRUTE_FORCE);
+//   img = distance_transform(im, DT_BRUTE_FORCE);
    if (!img)
       animal_err_default_reporter();
 
